==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/ExpressionV2Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.ExpressionV2Args.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.ExpressionV2Type
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Nested representation of a complex expression.
 * @property operands List of nested expressions.
 * @property operator Expression operator value Type: string.
 * @property type Type of expressions supported by the system. Type: string.
 * @property value Value for Constant/Field Type: string.
 */
public data class ExpressionV2Args(
    public val operands: Output<List<ExpressionV2Args>>? = null,
    public val `operator`: Output<String>? = null,
    public val type: Output<Either<String, ExpressionV2Type>>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.ExpressionV2Args> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.ExpressionV2Args =
        com.pulumi.azurenative.datafactory.inputs.ExpressionV2Args.builder()
            .operands(
                operands?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .`operator`(`operator`?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExpressionV2Args].
 */
@PulumiTagMarker
public class ExpressionV2ArgsBuilder internal constructor() {
    private var operands: Output<List<ExpressionV2Args>>? = null

    private var `operator`: Output<String>? = null

    private var type: Output<Either<String, ExpressionV2Type>>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value List of nested expressions.
     */
    @JvmName("dbhkxmveqsvnrixb")
    public suspend fun operands(`value`: Output<List<ExpressionV2Args>>) {
        this.operands = value
    }

    @JvmName("xolteshwqpyhwbjh")
    public suspend fun operands(vararg values: Output<ExpressionV2Args>) {
        this.operands = Output.all(values.asList())
    }

    /**
     * @param values List of nested expressions.
     */
    @JvmName("sjrexriddsjxmeum")
    public suspend fun operands(values: List<Output<ExpressionV2Args>>) {
        this.operands = Output.all(values)
    }

    /**
     * @param value Expression operator value Type: string.
     */
    @JvmName("odrjhvpfdnfqosjs")
    public suspend fun `operator`(`value`: Output<String>) {
        this.`operator` = value
    }

    /**
     * @param value Type of expressions supported by the system. Type: string.
     */
    @JvmName("boeofpmjbmtmpstq")
    public suspend fun type(`value`: Output<Either<String, ExpressionV2Type>>) {
        this.type = value
    }

    /**
     * @param value Value for Constant/Field Type: string.
     */
    @JvmName("hxdcbjvpeqcaalkm")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value List of nested expressions.
     */
    @JvmName("eimyokrvuamusdwq")
    public suspend fun operands(`value`: List<ExpressionV2Args>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.operands = mapped
    }

    /**
     * @param argument List of nested expressions.
     */
    @JvmName("vtciqydguwtftntx")
    public suspend fun operands(argument: List<suspend ExpressionV2ArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ExpressionV2ArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.operands = mapped
    }

    /**
     * @param argument List of nested expressions.
     */
    @JvmName("srnewairigkeeyiv")
    public suspend fun operands(vararg argument: suspend ExpressionV2ArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ExpressionV2ArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.operands = mapped
    }

    /**
     * @param argument List of nested expressions.
     */
    @JvmName("osvqhpxrkcggdcyr")
    public suspend fun operands(argument: suspend ExpressionV2ArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ExpressionV2ArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.operands = mapped
    }

    /**
     * @param values List of nested expressions.
     */
    @JvmName("tlmnrokngdjkwjfv")
    public suspend fun operands(vararg values: ExpressionV2Args) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operands = mapped
    }

    /**
     * @param value Expression operator value Type: string.
     */
    @JvmName("qqnkhofgccrwqaio")
    public suspend fun `operator`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value Type of expressions supported by the system. Type: string.
     */
    @JvmName("gvjnwbulqhcinkmg")
    public suspend fun type(`value`: Either<String, ExpressionV2Type>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of expressions supported by the system. Type: string.
     */
    @JvmName("hvfvtusdbuadkyba")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExpressionV2Type>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of expressions supported by the system. Type: string.
     */
    @JvmName("ncfnaqjjovvreato")
    public fun type(`value`: ExpressionV2Type) {
        val toBeMapped = Either.ofRight<String, ExpressionV2Type>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Value for Constant/Field Type: string.
     */
    @JvmName("vxtxwwqhoemojjde")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ExpressionV2Args = ExpressionV2Args(
        operands = operands,
        `operator` = `operator`,
        type = type,
        `value` = `value`,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/ExpressionV2Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.ExpressionV2Args.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.ExpressionV2Type
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Nested representation of a complex expression.
 * @property operands List of nested expressions.
 * @property operator Expression operator value Type: string.
 * @property type Type of expressions supported by the system. Type: string.
 * @property value Value for Constant/Field Type: string.
 */
public data class ExpressionV2Args(
    public val operands: Output<List<ExpressionV2Args>>? = null,
    public val `operator`: Output<String>? = null,
    public val type: Output<Either<String, ExpressionV2Type>>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.ExpressionV2Args> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.ExpressionV2Args =
        com.pulumi.azurenative.datafactory.inputs.ExpressionV2Args.builder()
            .operands(
                operands?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .`operator`(`operator`?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExpressionV2Args].
 */
@PulumiTagMarker
public class ExpressionV2ArgsBuilder internal constructor() {
    private var operands: Output<List<ExpressionV2Args>>? = null

    private var `operator`: Output<String>? = null

    private var type: Output<Either<String, ExpressionV2Type>>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value List of nested expressions.
     */
    @JvmName("uxccbxanbxweoybh")
    public suspend fun operands(`value`: Output<List<ExpressionV2Args>>) {
        this.operands = value
    }

    @JvmName("wabhckihytehsufa")
    public suspend fun operands(vararg values: Output<ExpressionV2Args>) {
        this.operands = Output.all(values.asList())
    }

    /**
     * @param values List of nested expressions.
     */
    @JvmName("akfjovbwavsanmgc")
    public suspend fun operands(values: List<Output<ExpressionV2Args>>) {
        this.operands = Output.all(values)
    }

    /**
     * @param value Expression operator value Type: string.
     */
    @JvmName("slkxilpdbiwojbdm")
    public suspend fun `operator`(`value`: Output<String>) {
        this.`operator` = value
    }

    /**
     * @param value Type of expressions supported by the system. Type: string.
     */
    @JvmName("wgrrsxpocmhfblfl")
    public suspend fun type(`value`: Output<Either<String, ExpressionV2Type>>) {
        this.type = value
    }

    /**
     * @param value Value for Constant/Field Type: string.
     */
    @JvmName("tkpbnldolyxgckie")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value List of nested expressions.
     */
    @JvmName("dygbopdusstndwyf")
    public suspend fun operands(`value`: List<ExpressionV2Args>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.operands = mapped
    }

    /**
     * @param argument List of nested expressions.
     */
    @JvmName("ivbjilxqryyckpdh")
    public suspend fun operands(argument: List<suspend ExpressionV2ArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ExpressionV2ArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.operands = mapped
    }

    /**
     * @param argument List of nested expressions.
     */
    @JvmName("cdnlvfahmxamnbck")
    public suspend fun operands(vararg argument: suspend ExpressionV2ArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ExpressionV2ArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.operands = mapped
    }

    /**
     * @param argument List of nested expressions.
     */
    @JvmName("otgcreawmcfdukaf")
    public suspend fun operands(argument: suspend ExpressionV2ArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ExpressionV2ArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.operands = mapped
    }

    /**
     * @param values List of nested expressions.
     */
    @JvmName("cskufvinlgeqoapx")
    public suspend fun operands(vararg values: ExpressionV2Args) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operands = mapped
    }

    /**
     * @param value Expression operator value Type: string.
     */
    @JvmName("fygufvajgsthgwpd")
    public suspend fun `operator`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value Type of expressions supported by the system. Type: string.
     */
    @JvmName("bblwhstdlvwhjeky")
    public suspend fun type(`value`: Either<String, ExpressionV2Type>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of expressions supported by the system. Type: string.
     */
    @JvmName("kgfqttcwhmrbqfsf")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExpressionV2Type>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Type of expressions supported by the system. Type: string.
     */
    @JvmName("vxilkkfgqgrcpayk")
    public fun type(`value`: ExpressionV2Type) {
        val toBeMapped = Either.ofRight<String, ExpressionV2Type>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Value for Constant/Field Type: string.
     */
    @JvmName("fgekivorhnlfgwyj")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ExpressionV2Args = ExpressionV2Args(
        operands = operands,
        `operator` = `operator`,
        type = type,
        `value` = `value`,
    )
}
